//! The main entrypoint for bootc-reinstall

use anyhow::{ensure, Context, Result};
use rustix::process::getuid;

mod config;
mod podman;
mod prompt;
pub(crate) mod users;

const ROOT_KEY_MOUNT_POINT: &str = "/bootc_authorized_ssh_keys/root";

fn run() -> Result<()> {
    bootc_utils::initialize_tracing();

    let config = config::ReinstallConfig::load().context("loading config")?;

    tracing::trace!("starting bootc-reinstall");
    // Rootless podman is not supported by bootc
    ensure!(getuid().is_root(), "Must run as the root user");
    let all_args = podman::command(&config.bootc_image, prompt::get_root_key()?);
    println!("Going to run command: {}", all_args.join(" "));
    prompt::temporary_developer_protection_prompt()?;
    podman::run_podman(all_args)?;
    Ok(())
}

fn main() {
    // In order to print the error in a custom format (with :#) our
    // main simply invokes a run() where all the work is done.
    // This code just captures any errors.
    if let Err(e) = run() {
        tracing::error!("{:#}", e);
        std::process::exit(1);
    }
}
